@@ -119,12 +119,14 @@ static int sinfo_new_get_vec ( float * xdat,
                         that is 
                         y = (parlist(0) - parlist(1)) / 
                             (1+exp((x-parlist(2))/parlist(3))) + parlist(1)
-
+  or 0 is the input are invalid
  */
 
 float sinfo_new_boltz ( float * xdat, float * parlist )
 {
     float return_value ;
+    cpl_ensure(xdat , CPL_ERROR_NULL_INPUT, 0.);
+    cpl_ensure(parlist , CPL_ERROR_NULL_INPUT, 0.);
 
     /* now build the boltzman function out of the parameters */
     return_value = 
@@ -156,9 +158,13 @@ float sinfo_new_boltz ( float * xdat, float * parlist )
   @returns               nothing, void
  */
 
-void sinfo_new_boltz_deriv( float * xdat, float * parlist, float * dervs )
+cpl_error_code sinfo_new_boltz_deriv( float * xdat, float * parlist, float * dervs )
 {
     float subst ;
+    cpl_ensure_code(xdat , CPL_ERROR_NULL_INPUT);
+    cpl_ensure_code(parlist , CPL_ERROR_NULL_INPUT);
+    cpl_ensure_code(dervs , CPL_ERROR_NULL_INPUT);
+
 
     subst = (xdat[0] - parlist[2]) / parlist[3] ;
 
@@ -172,6 +178,8 @@ void sinfo_new_boltz_deriv( float * xdat, float * parlist, float * dervs )
     dervs[3] = ( (parlist[0] - parlist[1]) * (xdat[0] - parlist[2]) /
                     (parlist[3]*parlist[3]) * exp(subst) ) /
                     ( (1. + exp(subst)) * (1. + exp(subst)) ) ;
+
+    return cpl_error_get_code();
 }
 
 /**
@@ -1508,7 +1516,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
           user given positions.
           The least squares fit is done by using a box smaller than
           the size of two slitlets
-
+TODO: NOT USED
  */
 
 int 
