@@ -82,6 +82,7 @@
            fitted through the fitted positions. The slope of this linear fit 
            is returned.
 
+TODO: not used
  */
 
 float 
@@ -407,6 +408,7 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
    @doc   shifts the rows of a raw image by using the output of
           sinfo_slopeOfSpectrum and applying polynomial interpolation
 
+TODO: not used
 
  */
 
@@ -642,7 +644,7 @@ sinfo_new_shift_rows( cpl_image * image,
    @param filename filename of ASCII file
 
    @return void
-
+TODO: NOT USED
  */
 
 void 
@@ -697,6 +699,7 @@ sinfo_new_parameter_to_ascii ( float * parameter,
        each row. Afterwards, a polynomial is fitted through the
        found positions. The polynomial coefficients are returned.
 
+TODO: NOT USED
  *
  */
 
