@@ -125,12 +125,10 @@ sinfo_fit_amoeba_get_psum(int ndim, int mpts, double** p, double* psum)
    @memo        Imp-lements amoeba function for multidimensional minimizzation
    @param        p matrix of size [1...ndim+1][1...ndim]
    @param        y vector[1...ndim+1]
-   @param        psum
    @param        ndim vector's dimension
+   @param        ftol fractional goal tolerance
    @param        funk function to be minimized
-   @param        ihi
-   @param        fac
-   @return    int 0, 1, or -1
+   @return    void
    @doc
    Multidimensional minimizzation of the function funk(x) where x[1..ndim] is
    a vector in ndim dimensions, by the downhill simplex method of Nedler and
@@ -310,6 +308,8 @@ sinfo_fit_amotry(double** p, double y[], double psum[], int ndim,
  @param    nref is the maximum number of reflections
  @param    ftbm function to be fit
  @note     parameters begin varying as d2(i)+-range(i)
+
+ TODO: not used
  */
 double
 sinfo_amsub(double d0[], double d1[], double d2[], double value[],
@@ -612,6 +612,7 @@ sinfo_spline(double x, double cons[], double ak[], double *sp, double *spp,
 
 }
 
+/* TODO: not used */
 double
 sinfo_ftbm(const double x, double cons[])
 {
