@@ -279,8 +279,8 @@ gauss_pivot(double *ptra, double *ptrc, int n)
 #define SINFO_ABS(a) (((a) > 0) ? (a) : -(a))
 
     register int i, j, k, l;
-    int maj;
-    double max, r, t;
+
+    double r, t;
     double *ptrb;
 
     ptrb = (double *) cpl_calloc(n * n, sizeof(double));
@@ -289,8 +289,8 @@ gauss_pivot(double *ptra, double *ptrc, int n)
 
     for (i = 1; i <= n; i++) {
         /* Search max in current column  */
-        max = SINFO_ABS(*(ptra + n*i-n));
-        maj = i;
+        double max = SINFO_ABS(*(ptra + n*i-n));
+        int maj = i;
         for (j = i; j <= n; j++)
             if (SINFO_ABS(*(ptra+n*j+i-n-1)) > max) {
                 maj = j;
