@@ -61,8 +61,214 @@
 /*----------------------------------------------------------------------------
                                 Defines
  ---------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------------*/
+/**
+ * @internal
+ * @brief    Find the aperture(s) with the greatest flux
+ * @param    self   The aperture object
+ * @param    ind  The aperture-indices in order of decreasing flux
+ * @param    nfind  Number of indices to find
+ * @return   CPL_ERROR_NONE or the relevant _cpl_error_code_ on error
+ *
+ * nfind must be at least 1 and at most the size of the aperture object.
+ *
+ * The ind array must be able to hold (at least) nfind integers.
+ * On success the first nfind elements of ind point to indices of the
+ * aperture object.
+ *
+ * To find the single ind of the aperture with the maximum flux use simply:
+ * int ind;
+ * sinfo_apertures_find_max_flux(self, &ind, 1);
+ *
+ */
+/*----------------------------------------------------------------------------*/
+static cpl_error_code sinfo_apertures_find_max_flux(const cpl_apertures * self,
+                                              int * ind, int nfind)
+{
+    const int    nsize = cpl_apertures_get_size(self);
+    int          ifind;
 
 
+    cpl_ensure_code(nsize > 0,      cpl_error_get_code());
+    cpl_ensure_code(ind,          CPL_ERROR_NULL_INPUT);
+    cpl_ensure_code(nfind > 0,      CPL_ERROR_ILLEGAL_INPUT);
+    cpl_ensure_code(nfind <= nsize, CPL_ERROR_ILLEGAL_INPUT);
+
+    for (ifind=0; ifind < nfind; ifind++) {
+        double maxflux = -1;
+        int maxind = -1;
+        int i;
+        for (i=1; i <= nsize; i++) {
+            int k;
+
+            /* The flux has to be the highest among those not already found */
+            for (k=0; k < ifind; k++) if (ind[k] == i) break;
+
+            if (k == ifind) {
+                /* i has not been inserted into ind */
+                const double flux = cpl_apertures_get_flux(self, i);
+
+                if (maxind < 0 || flux > maxflux) {
+                    maxind = i;
+                    maxflux = flux;
+                }
+            }
+        }
+        ind[ifind] = maxind;
+    }
+
+    return CPL_ERROR_NONE;
+
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @internal
+ * @brief    Find the peak flux, peak sum and position of a Gaussian
+ * @param    self        Image to process
+ * @param    sigma       The initial detection level  [ADU]
+ * @param    pxpos       On success, the refined X-position [pixel]
+ * @param    pypos       On success, the refined Y-position [pixel]
+ * @param    ppeak       On success, the refined peak flux  [ADU]
+ * @return CPL_ERROR_NONE or the relevant CPL error code on error
+ *
+ * The routine initially determines the approximate position and flux value of
+ * the PSF with a robust Gaussian fit: first are identified all sources that lie
+ * 5 sigmas above the median of the image, then is determined the position of
+ * the barycenter of the region with highest peak. Finally is performed the fit
+ * of a Gaussian centered on the found barycenter position.
+ *
+ */
+/*----------------------------------------------------------------------------*/
+static cpl_error_code
+sinfo_gaussian_maxpos(const cpl_image * self,
+                double sigma,
+                double  * pxpos,
+                double  * pypos,
+                double  * ppeak)
+{
+    /* copied from irplib_strehl.c r163170 */
+    const cpl_size  nx = cpl_image_get_size_x(self);
+    const cpl_size  ny = cpl_image_get_size_y(self);
+    int             iretry = 3; /* Number retries with decreasing sigma */
+    int             ifluxapert = 0;
+    double          med_dist;
+    const double    median = cpl_image_get_median_dev(self, &med_dist);
+    cpl_mask      * selection;
+    cpl_size        nlabels = 0;
+    cpl_image     * labels = NULL;
+    cpl_apertures * aperts;
+    cpl_size        npixobj;
+    double          objradius;
+    cpl_size        winsize;
+    cpl_size        xposmax, yposmax;
+    double          xposcen, yposcen;
+    double          valmax, valfit = -1.0;
+    cpl_array     * gauss_parameters = NULL;
+    cpl_errorstate  prestate = cpl_errorstate_get();
+    cpl_error_code  code = CPL_ERROR_NONE;
+
+
+    cpl_ensure_code( sigma > 0.0, CPL_ERROR_ILLEGAL_INPUT);
+
+    selection = cpl_mask_new(nx, ny);
+
+    /* find aperture with signal larger than sigma * median deviation */
+    for (; iretry > 0 && nlabels == 0; iretry--, sigma *= 0.5) {
+
+        /* Compute the threshold */
+        const double threshold = median + sigma * med_dist;
+
+
+        /* Select the pixel above the threshold */
+        code = cpl_mask_threshold_image(selection, self, threshold, DBL_MAX,
+                                        CPL_BINARY_1);
+
+        if (code) break;
+
+        /* Labelise the thresholded selection */
+        cpl_image_delete(labels);
+        labels = cpl_image_labelise_mask_create(selection, &nlabels);
+    }
+    sigma *= 2.0; /* reverse last iteration that found no labels */
+
+    cpl_mask_delete(selection);
+
+    if (code) {
+        cpl_image_delete(labels);
+        return cpl_error_set_where(cpl_func);
+    } else if (nlabels == 0) {
+        cpl_image_delete(labels);
+        return cpl_error_set(cpl_func, CPL_ERROR_DATA_NOT_FOUND);
+    }
+
+    aperts = cpl_apertures_new_from_image(self, labels);
+
+    /* Find the aperture with the greatest flux */
+    code = sinfo_apertures_find_max_flux(aperts, &ifluxapert, 1);
+
+    if (code) {
+        cpl_apertures_delete(aperts);
+        cpl_image_delete(labels);
+        return cpl_error_set(cpl_func, CPL_ERROR_DATA_NOT_FOUND);
+    }
+
+    npixobj = cpl_apertures_get_npix(aperts, ifluxapert);
+    objradius = sqrt((double)npixobj * CPL_MATH_1_PI);
+    winsize = CX_MIN(CX_MIN(nx, ny), (3.0 * objradius));
+
+    xposmax = cpl_apertures_get_maxpos_x(aperts, ifluxapert);
+    yposmax = cpl_apertures_get_maxpos_y(aperts, ifluxapert);
+    xposcen = cpl_apertures_get_centroid_x(aperts, ifluxapert);
+    yposcen = cpl_apertures_get_centroid_y(aperts, ifluxapert);
+    valmax  = cpl_apertures_get_max(aperts, ifluxapert);
+
+    cpl_apertures_delete(aperts);
+    cpl_image_delete(labels);
+
+    cpl_msg_debug(cpl_func, "Object radius at S/R=%g: %g (window-size=%u)",
+                  sigma, objradius, (unsigned)winsize);
+    cpl_msg_debug(cpl_func, "Object-peak @ (%d, %d) = %g", (int)xposmax,
+                  (int)yposmax, valmax);
+
+    /* fit gaussian to get subpixel peak position */
+
+    gauss_parameters = cpl_array_new(7, CPL_TYPE_DOUBLE);
+    cpl_array_set_double(gauss_parameters, 0, median);
+
+    code = cpl_fit_image_gaussian(self, NULL, xposmax, yposmax,
+                                  winsize, winsize, gauss_parameters,
+                                  NULL, NULL, NULL,
+                                  NULL, NULL, NULL,
+                                  NULL, NULL, NULL);
+    if (!code) {
+        const double M_x = cpl_array_get_double(gauss_parameters, 3, NULL);
+        const double M_y = cpl_array_get_double(gauss_parameters, 4, NULL);
+
+        valfit = cpl_gaussian_eval_2d(gauss_parameters, M_x, M_y);
+
+        if (!cpl_errorstate_is_equal(prestate)) {
+            code = cpl_error_get_code();
+        } else {
+            *pxpos        = M_x;
+            *pypos        = M_y;
+            *ppeak        = valfit;
+
+            cpl_msg_debug(cpl_func, "Gauss-fit @ (%g, %g) = %g",
+                          M_x, M_y, valfit);
+        }
+    }
+    cpl_array_delete(gauss_parameters);
+
+    if (code || valfit < valmax) {
+        cpl_errorstate_set(prestate);
+        *pxpos   = xposcen;
+        *pypos   = yposcen;
+        *ppeak   = valmax;
+    }
+
+    return code ? cpl_error_set_where(cpl_func) : CPL_ERROR_NONE;
+}
+
 /*----------------------------------------------------------------------------
                              Function Definitions
  ---------------------------------------------------------------------------*/
@@ -195,7 +401,6 @@ sinfo_new_stdstar(const char* plugin_id,
 
     cknull(cfg=sinfo_parse_cpl_input_standstar(config,sof,&raw),
        "could not parse cpl input!") ;
-
  
     cknull_nomsg(p = cpl_parameterlist_find(config,
 				     "sinfoni.std_star.compute_eff"));
@@ -232,7 +437,6 @@ sinfo_new_stdstar(const char* plugin_id,
       goto cleanup;
     }
 
-
     cknull(plist = cpl_propertylist_load(std_cub_filename, 0),
       "getting header from reference ima frame %s",std_cub_filename);
 
@@ -252,7 +456,6 @@ sinfo_new_stdstar(const char* plugin_id,
 
     /* we find automatiocally extraction parameters */
 
-
     if(NULL != cpl_frameset_find(sof,PRO_MED_COADD_STD)) {
       frame = cpl_frameset_find(sof,PRO_MED_COADD_STD);
       strcpy(std_med_filename,cpl_frame_get_filename(frame));
@@ -313,8 +516,8 @@ sinfo_new_stdstar(const char* plugin_id,
       goto cleanup;
     }
 
-
     check_nomsg(std_med_dup=cpl_image_duplicate(std_med_ima));
+    cpl_image_reject_value(std_med_dup,CPL_VALUE_NAN);
     sinfo_clean_nan(&std_med_dup);
     ima_szx=cpl_image_get_size_x(std_med_ima);
     ima_szy=cpl_image_get_size_y(std_med_ima);
@@ -325,9 +528,21 @@ sinfo_new_stdstar(const char* plugin_id,
      * using HDRL.
      */
     int margin=3;
+    cpl_image_reject_value(std_med_dup,CPL_VALUE_NAN);
+
+    double peak=0;
+    double max_x;
+    double max_y;
+    sinfo_gaussian_maxpos(std_med_dup,5,&max_x,&max_y,&peak);
+    max_ima_x=(int)(max_x+0.5);
+    max_ima_y=(int)(max_y+0.5);
+
+    /* This is not robust
     check_nomsg(cpl_image_get_maxpos_window(std_med_dup,
                     margin,margin,ima_szx-margin,ima_szy-margin,
                     &max_ima_x,&max_ima_y));
+     */
+
     sinfo_free_image(&std_med_dup);
 
 
@@ -349,6 +564,8 @@ sinfo_new_stdstar(const char* plugin_id,
 
       xshift=max_ima_cx-ima_szx/2;
       yshift=max_ima_cy-ima_szy/2;
+      xshift=max_x-ima_szx/2;
+      yshift=max_y-ima_szy/2;
 
       ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC SHIFTX",xshift,
                                        "X shift centroid - center image","%f"));
@@ -532,7 +749,6 @@ sinfo_new_stdstar(const char* plugin_id,
 
      }
 
-
 	ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC CHECK2",
                                        check2,"Check on evaluation box","%d"));
 
@@ -562,8 +778,6 @@ sinfo_new_stdstar(const char* plugin_id,
      }
 
 
-
-
      /*
          if(spectrum[fra] != NULL ) {
          sinfo_free_image(&(spectrum)[fra]);
