@@ -298,19 +298,6 @@ int sinfo_pfits_get_rom(const cpl_propertylist * plist)
 
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the number of the current exposition  
-  @param    plist input propertylist
-  @return   keyword value 
- */
-/*---------------------------------------------------------------------------*/
-int sinfo_pfits_get_expno(const cpl_propertylist * plist)
-{
-
-    return cpl_propertylist_get_int(plist,"ESO TPL EXPNO");
-
-}
 
 
 /*---------------------------------------------------------------------------*/
@@ -340,18 +327,6 @@ double sinfo_pfits_get_airmass_end(const cpl_propertylist * plist)
 
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the alpha angle
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-double sinfo_pfits_get_alpha(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_double(plist,"ESO TEL TARG OFFSETALPHA");
-}
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the targ alpha angle
@@ -389,18 +364,6 @@ const char * sinfo_pfits_get_arcfile(const cpl_propertylist * plist)
     return (const char*) cpl_propertylist_get_string(plist,KEY_NAME_ARCFILE);
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the arcfile   
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_rec1raw1name(const cpl_propertylist * plist)
-{
-    return (const char*) cpl_propertylist_get_string(plist,
-                    KEY_NAME_PRO_REC1_RAW1_NAME);
-}
 
 /*---------------------------------------------------------------------------*/
 /**
@@ -421,34 +384,6 @@ const char * sinfo_pfits_get_ins_setup(const cpl_propertylist * plist)
 }
 
 
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the central wavelength
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-double sinfo_pfits_get_wlen(const cpl_propertylist * plist)
-{
-
-    return cpl_propertylist_get_double(plist,"ESO INS GRAT1 WLEN");
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the number of chopping cycles
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-int sinfo_pfits_get_chop_ncycles(const cpl_propertylist * plist)
-{
-
-    return cpl_propertylist_get_int(plist,"ESO DET CHOP NCYCLES");
-
-}
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the number of chopping cycles
@@ -526,20 +461,6 @@ const char * sinfo_pfits_get_date_obs(const cpl_propertylist * plist)
 
 }
 
-/*---------------------------------------------------------------------------*/
-/** 
-  @brief    find out the DELTA keyword in a SINFONI header
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-double  sinfo_pfits_get_delta(const cpl_propertylist * plist)
-{
-
-    return cpl_propertylist_get_double(plist,"ESO TEL TARG OFFSETDELTA");
-
-}
-
 /*---------------------------------------------------------------------------*/
 /** 
   @brief    find out the DEC keyword in a SINFONI header
@@ -583,21 +504,6 @@ float sinfo_pfits_get_pixelscale(const char * name)
     return pixscale;
 }
 
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the character string associated to the DIT keyword
-            in an sinfoni header
-  @param    plist    FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_ncorrs_name(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO DET NCORRS NAME");
-}
-
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the character string associated to the FILT1.NAME keyword
@@ -611,43 +517,6 @@ const char * sinfo_pfits_get_band(const cpl_propertylist * plist)
     return cpl_propertylist_get_string(plist,"ESO INS FILT1 NAME");
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the data category as defined by the DataFlow
-  @param    plist   FITS header
-  @return   statically allocated char string, no need to free() it
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_dpr_catg(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO DPR CATG");
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the data tech as defined by the DataFlow
-  @param    plist    FITS header
-  @return   statically allocated char string, no need to free() it
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_dpr_tech(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO DPR TECH");
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the data type as defined by the DataFlow
-  @param    plist   FITS header
-  @return   statically allocated char string, no need to free() it
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_dpr_type(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO DPR TYPE");
-}
-
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the filter in imaging 
@@ -660,43 +529,6 @@ const char * sinfo_pfits_get_filter_im(const cpl_propertylist * plist)
     return cpl_propertylist_get_string(plist,"ESO INS FILT1 NAME");
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the filter in spectroscopy 
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_filter_spec(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO INS FILT2 NAME");
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the character string associated to the FOCUS keyword
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-double sinfo_pfits_get_focus(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_double(plist,"ESO TEL FOCU LEN");
-}
-
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the frame type   
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_frame_type(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO DET FRAM TYPE");
-}
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the character string associated to the instrument
@@ -906,43 +738,6 @@ double sinfo_pfits_get_crval3(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist,"CRVAL3");
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the number of expositions  
-  @param    plist    FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-int sinfo_pfits_get_numbexp(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_int(plist,"ESO TPL NEXP");
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the OBS ID keyword 
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_obs_id(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO OBS ID");
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the character string associated to nodding position
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-int sinfo_pfits_get_nodpos(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_int(plist,"ESO SEQ NODPOS");
-}
-
-
 
 /*---------------------------------------------------------------------------*/
 /**
@@ -956,18 +751,6 @@ double sinfo_pfits_get_ra(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist,"RA");
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the std star name 
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_starname(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO OBS TARG NAME");
-}
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the spectral resolution
@@ -980,17 +763,6 @@ double sinfo_pfits_get_resol(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist,"ESO INS RESOL");
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the template id    
-  @param    plist    FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_templateid(const cpl_propertylist * plist)
-{
-    return (const char*) cpl_propertylist_get_string(plist,"ESO TPL ID"); 
-}
 /**
 @brief set hdu keys 
 @param plist input propertylist
