@@ -213,286 +213,6 @@ sinfo_update_ims_fits_card_string(cpl_imagelist* iml,
     cpl_propertylist_delete(plist) ;
     return 0;
 }
-/* Not used 
-static int sinfo_save_paf(char* name_p, 
-			  const char* rec_id, 
-			  cpl_table* qclog,
-			  cpl_propertylist*   plist,
-			  const char*      pro_catg)
-{
-
-
-
-  FILE            *   paf ;
-  const char            *   sval ;
-  char            key_name[FILE_NAME_SZ] ;
-  char            key_paf[FILE_NAME_SZ] ;
-  char            key_dpaf[FILE_NAME_SZ] ;
-  char            key_type[FILE_NAME_SZ] ;
-  char            key_value[FILE_NAME_SZ] ;
-  double dval=0;
-
-  int i =0;
-  int n=0;
-  sinfo_msg( "Writing %s" , name_p) ;
-  // Create the default PAF header
-  if ((paf = sinfo_paf_print_header(name_p,rec_id,"QC file","login-name",
-				    sinfo_get_datetime_iso8601())) == NULL) {
-    sinfo_msg_error( "cannot open file [%s] for output", name_p) ;
-    return -1 ;
-  }
-  if (sinfo_check_rec_status(0) == -1) {
-    sinfo_msg_error( "Something was wrong") ;
-    return -1 ;
-  }
-
-  // Test entries
-  sinfo_blank2dot(PAF_NAME_PIPE_ID,key_dpaf);
-  fprintf(paf,"%-21s \"%s\" ;# %s\" \n", key_dpaf,
-	  VERSION,KEY_HELP_PIPE_ID);
-
-  strcpy(key_name,KEY_NAME_PIPEFILE);        
-  strcpy(key_paf,KEY_NAME_PIPEFILE);        
-  sinfo_blank2dot(key_paf,key_dpaf);
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s \"%s\" ;# %s\" \n",key_dpaf,
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PIPEFILE);
-  }
-
-  // Value: "TEMPORARY", "PREPROCESSED", "REDUCED" or "QCPARAM".
-  strcpy(key_name,KEY_NAME_PRO_TYPE);
-  strcpy(key_paf,PAF_NAME_PRO_TYPE);    
-  sinfo_blank2dot(key_paf,key_dpaf);
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s \"%s\" ;# %s\" \n", key_dpaf,
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PRO_TYPE);
-  }
-
-  strcpy(key_name,KEY_NAME_PRO_DATANCOM); 
-  strcpy(key_paf,PAF_NAME_PRO_DATANCOM); 
-  sinfo_blank2dot(key_paf,key_dpaf);
-  if (cpl_propertylist_has(plist,key_name)) {
-    fprintf(paf,"%-21s %d ;# %s\" \n",key_dpaf,
-	    cpl_propertylist_get_int(plist,key_name),KEY_HELP_PRO_DATANCOM);
-  }
-
-  strcpy(key_name,KEY_NAME_NCORRS_NAME);
-  strcpy(key_paf,PAF_NAME_NCORRS_NAME);
-  sinfo_blank2dot(key_paf,key_dpaf);
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s \"%s\" ;# %s \n", key_dpaf,
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_NCORRS_NAME);
-  }
-
-  strcpy(key_name,KEY_NAME_DET_NDSAMPLES);
-  strcpy(key_paf,PAF_NAME_DET_NDSAMPLES);
-  sinfo_blank2dot(key_paf,key_dpaf);        
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s %d ;# %s \n",key_dpaf, 
-	    cpl_propertylist_get_int(plist,key_name),KEY_HELP_DET_NDSAMPLES);
-  }
-
-  strcpy(key_name,KEY_NAME_FILT_NAME);      
-  strcpy(key_paf,PAF_NAME_FILT_NAME);      
-  sinfo_blank2dot(key_paf,key_dpaf);        
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s \"%s\" ;# %s \n", key_dpaf,
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_FILT_NAME);
-  }
-
-  strcpy(key_name,KEY_NAME_FILT_ID);        
-  strcpy(key_paf,PAF_NAME_FILT_ID);        
-  sinfo_blank2dot(key_paf,key_dpaf);        
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s \"%s\" ;# %s \n",key_dpaf, 
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_FILT_ID);
-  }
-
-  strcpy(key_name,KEY_NAME_PREOPTICS);        
-  strcpy(key_paf,PAF_NAME_PREOPTICS);        
-  sinfo_blank2dot(key_paf,key_dpaf);        
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s \"%s\" ;# %s \n",key_dpaf, 
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PREOPTICS);
-  }
-
-  strcpy(key_name,KEY_NAME_GRAT_NAME);        
-  strcpy(key_paf,PAF_NAME_GRAT_NAME);        
-  sinfo_blank2dot(key_paf,key_dpaf);        
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf, "%-21s \"%s\" ;# %s \n",key_dpaf, 
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_GRAT_NAME);
-  }
-
-  strcpy(key_name,KEY_NAME_GRAT_WLEN);        
-  strcpy(key_paf,PAF_NAME_GRAT_WLEN);        
-  sinfo_blank2dot(key_paf,key_dpaf);        
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf, "%-21s %f ;# %s \n", key_dpaf,
-	    cpl_propertylist_get_double(plist,key_name),KEY_HELP_GRAT_WLEN);
-  }
-
-  strcpy(key_name,KEY_NAME_PRO_RECID);  
-  strcpy(key_paf,PAF_NAME_PRO_RECID);  
-  sinfo_blank2dot(key_paf,key_dpaf);        
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s \"%s\" ;# %s \n", key_dpaf,
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PRO_RECID);
-  }
-
-
-  // snprintf(cval, MAX_NAME_SIZE-1,"CPL-%s", get_cpl_version());
-  strcpy(key_name,KEY_NAME_PRO_DRSID); 
-  strcpy(key_paf,PAF_NAME_PRO_DRSID); 
-  sinfo_blank2dot(key_paf,key_dpaf);        
-  if (cpl_propertylist_has(plist, key_name)) {
-    fprintf(paf,"%-21s \"%s\" ;# %s \n",key_dpaf, 
-	    cpl_propertylist_get_string(plist,key_name),KEY_HELP_PRO_DRSID);
-  }
-
-  if (cpl_propertylist_has(plist,KEY_NAME_DATE_OBS)) {
-    sval = sinfo_pfits_get_date_obs(plist);
-    strcpy(key_paf,KEY_NAME_DATE_OBS); 
-    sinfo_blank2dot(key_paf,key_dpaf);        
-    fprintf(paf, "%-21s \"%s\" ;# %s\n",key_dpaf, 
-	    sval,KEY_HELP_DATE_OBS) ;
-  }
-
-
-  if (cpl_propertylist_has(plist,KEY_NAME_TEL_AIRM_START)) {
-    dval = sinfo_pfits_get_airmass_start(plist);
-    strcpy(key_paf,PAF_NAME_TEL_AIRM_START); 
-    sinfo_blank2dot(key_paf,key_dpaf);        
-    fprintf(paf, "%-21s \"%f\" ;# %s \n",key_dpaf, 
-	    dval,KEY_HELP_TEL_AIRM_START) ;
-  }
-
-  if (cpl_propertylist_has(plist,KEY_NAME_ARCFILE)) {
-    sval = sinfo_pfits_get_arcfile(plist);
-    strcpy(key_paf,KEY_NAME_ARCFILE);
-    sinfo_blank2dot(key_paf,key_dpaf);      
-    fprintf(paf, "%-21s \"%s\" ;# %s \n", key_dpaf,sval,KEY_HELP_ARCFILE) ;
-
-  } else if (cpl_propertylist_has(plist,KEY_NAME_PRO_REC1_RAW1_NAME)) {
-    sval = sinfo_pfits_get_rec1raw1name(plist);
-    strcpy(key_paf,KEY_NAME_ARCFILE);
-    sinfo_blank2dot(key_paf,key_dpaf);       
-    fprintf(paf, "%-21s \"%s\" ;# %s \n", key_dpaf,sval,KEY_HELP_ARCFILE) ;
-  } else {
-    sinfo_msg_error("%s is missing QC LOG will fail!",KEY_NAME_ARCFILE);
-  }
-
-  if (cpl_propertylist_has(plist,KEY_NAME_TPL_ID)) {
-    sval = sinfo_pfits_get_templateid(plist);
-    strcpy(key_paf,PAF_NAME_TPL_ID);
-    sinfo_blank2dot(key_paf,key_dpaf);       
-    fprintf(paf, "%-21s \"%s\" ; # %s\n", key_dpaf,
-	    sval,KEY_HELP_TPL_ID) ;
-
-  }
-
-  if (cpl_propertylist_has(plist,KEY_NAME_DET_DIT)) { 
-    strcpy(key_paf,PAF_NAME_DET_DIT); 
-    sinfo_blank2dot(key_paf,key_dpaf);        
-    fprintf(paf,"%-21s %f ; # %s\n", key_dpaf,
-	    sinfo_pfits_get_dit(plist),KEY_HELP_DET_DIT) ;
-  }
-
-
-  if (cpl_propertylist_has(plist,KEY_NAME_DET_NDIT)) {
-    strcpy(key_paf,PAF_NAME_DET_NDIT); 
-    sinfo_blank2dot(key_paf,key_dpaf); 
-    fprintf(paf,"%-21s %d ; # %s\n", key_dpaf,
-	    sinfo_pfits_get_ndit(plist),KEY_HELP_DET_NDIT) ;
-  }
-
-  if (cpl_propertylist_has(plist,KEY_NAME_NCORRS_NAME)) {
-    sval = sinfo_pfits_get_ncorrs_name(plist);
-    strcpy(key_paf,PAF_NAME_NCORRS_NAME); 
-    sinfo_blank2dot(key_paf,key_dpaf);        
-
-    fprintf(paf, "%-21s \"%s\" ; # %s\n", key_dpaf,
-	    sval, KEY_HELP_NCORRS_NAME) ;
-  }
-
-  if (cpl_propertylist_has(plist,KEY_NAME_DPR_TYPE)) {
-    sval = sinfo_pfits_get_dpr_type(plist);
-    strcpy(key_paf,PAF_NAME_DPR_TYPE); 
-    sinfo_blank2dot(key_paf,key_dpaf);        
-    fprintf(paf, "%-21s \"%s\" ; # %s\n", key_dpaf,
-	    sval, KEY_HELP_DPR_TYPE) ;
-  }
-
-  if (cpl_propertylist_has(plist,KEY_NAME_DPR_TECH)) {
-    sval = sinfo_pfits_get_dpr_tech(plist);
-    strcpy(key_paf,PAF_NAME_DPR_TECH); 
-    sinfo_blank2dot(key_paf,key_dpaf);   
-    fprintf(paf, "%-21s \"%s\" ; # %s\n", key_dpaf,
-	    sval, KEY_HELP_DPR_TECH) ;
-  }
-
-
-  if (cpl_propertylist_has(plist,KEY_NAME_DPR_CATG)) {
-    sval = sinfo_pfits_get_dpr_catg(plist);
-    strcpy(key_paf,PAF_NAME_DPR_CATG); 
-    sinfo_blank2dot(key_paf,key_dpaf); 
-    fprintf(paf, "%-21s \"%s\" ; # %s\n", key_dpaf,
-	    sval, KEY_HELP_DPR_CATG) ;
-  }
-
-  strcpy(key_paf,PAF_NAME_PRO_CATG); 
-  sinfo_blank2dot(key_paf,key_dpaf); 
-  fprintf(paf, "%-21s \"%s\" ; # %s\n", key_dpaf,
-	  pro_catg, KEY_HELP_PRO_CATG) ;
-
-  if (cpl_propertylist_has(plist,KEY_NAME_INS_SETUP)) {
-    sval = sinfo_pfits_get_ins_setup(plist);
-    strcpy(key_paf,PAF_NAME_INS_SETUP); 
-    sinfo_blank2dot(key_paf,key_dpaf); 
-    fprintf(paf, "%-21s \"%s\" ; # %s\n", key_dpaf,
-	    sval, KEY_HELP_INS_SETUP) ;
-  }
-
-  n=cpl_table_get_nrow(qclog);
-  for(i=0;i<n;i++) {
-    strcpy(key_paf,cpl_table_get_string(qclog,"key_name",i));
-    sinfo_blank2dot(key_paf,key_name);
-    strcpy(key_type,cpl_table_get_string(qclog,"key_type",i));
-    strcpy(key_value,cpl_table_get_string(qclog,"key_value",i));
-    if(strcmp(key_type,"CPL_TYPE_STRING") == 0) {
-      strcat(key_name,"               \"%s\"\n");
-      fprintf(paf, key_name, key_value) ;
-    } else if(strcmp(key_type,"CPL_TYPE_BOOL") == 0) {
-      strcat(key_name,"               ");
-      strcat(key_name,"%c\n");
-      fprintf(paf, key_name, atoi(key_value)) ;
-    } else if(strcmp(key_type,"CPL_TYPE_INT") == 0) {
-      strcat(key_name,"               ");
-      strcat(key_name,"%d\n");
-      fprintf(paf, key_name, atoi(key_value)) ;
-    } else if(strcmp(key_type,"CPL_TYPE_FLOAT") == 0) {
-      strcat(key_name,"               ");
-      strcat(key_name,"%g\n");
-      fprintf(paf, key_name, (float) atof(key_value)) ;
-    } else if(strcmp(key_type,"CPL_TYPE_DOUBLE") == 0) {
-      strcat(key_name,"               ");
-      strcat(key_name,"%g\n");
-      fprintf(paf, key_name, atof(key_value)) ;
-    }
-
-  }
-  fprintf(paf, "\n");
-  fclose(paf) ;
-
-  if (sinfo_check_rec_status(1) == -1) {
-    sinfo_msg_error( "Something was wrong reading FITS keys") ;
-    return -1 ;
-  }
-  return 0;
-
-}
-
- */
 
 /*---------------------------------------------------------------------------*/
 /**
@@ -574,12 +294,6 @@ int sinfo_pro_save_ima(
         return -1 ;
     }
 
-    /* THE PAF FILE FOR QC PARAMETERS
-     if( qclog != NULL) {
-     sinfo_save_paf(name_p,recid,qclog,plist,pro_catg);  
-     }
-     */
-
     cpl_propertylist_delete(plist) ;
     cpl_msg_indent_less() ;
     cpl_free(name_o);
@@ -665,12 +379,6 @@ int sinfo_pro_save_tbl(
         return -1 ;
     }
 
-
-    /* THE PAF FILE FOR QC PARAMETERS
-     if (qclog != NULL) {
-     sinfo_save_paf(name_p,recid,qclog,plist,pro_catg);
-     }
-     */
     cpl_propertylist_delete(plist) ;
     cpl_msg_indent_less() ;
     cpl_free(name_o);
@@ -765,11 +473,6 @@ int sinfo_pro_save_ims(
         return -1 ;
     }
 
-    /* THE PAF FILE FOR QC PARAMETERS
-     if (qclog != NULL) {
-     sinfo_save_paf(name_p,recid,qclog,plist,pro_catg);
-     }
-     */
     cpl_propertylist_delete(plist) ;
     cpl_msg_indent_less() ;
     cpl_free(name_o);
