@@ -269,8 +269,68 @@ sinfo_sess2deg(const double sess)
   return deg;
 
 }
+static cpl_error_code
+sinfo_offset_xy_fill(object_config * cfg, float* offsetx, float* offsety)
+{
+    cpl_propertylist * plist=NULL;
+    const int nframes = cfg->nframes;
 
+    for ( int n = 0 ; n < nframes ; n++ ) {
+        char* name = cfg->framelist[n] ;
+        plist=cpl_propertylist_load(name,0);
 
+        float offx = sinfo_pfits_get_cumoffsetx(plist);  /* was - */
+        if(cpl_error_get_code() != CPL_ERROR_NONE) {
+            sinfo_msg_warning(" could not read fits header keyword cummoffsetx!");
+            sinfo_msg_warning(" set it to  0");
+            offx = 0;
+            sinfo_free_propertylist(&plist);
+            cpl_error_reset();
+            /* return -1 ; */
+        }
+
+        offsetx[n]=offx;
+        float offy = sinfo_pfits_get_cumoffsety(plist); /* was - */
+        if(cpl_error_get_code() != CPL_ERROR_NONE) {
+            sinfo_msg_warning(" could not read fits header keyword! cumoffsety") ;
+            sinfo_msg_warning(" set it to 0");
+            offy = 0;
+            sinfo_free_propertylist(&plist);
+            cpl_error_reset();
+            /* return -1 ; */
+        }
+        offsety[n]=offy;
+        sinfo_free_propertylist(&plist);
+
+    }
+    return cpl_error_get_code();
+}
+
+static void
+sinfo_get_xy_min_max(const int nframes,
+                     const float* offsetx, const float* offsety,
+                     float* min_offx, float* max_offx,
+                     float* min_offy, float* max_offy)
+{
+
+    for ( int n = 0 ; n < nframes ; n++ ) {
+        float offx = offsetx[n];  /* was - */
+        float offy = offsety[n];  /* was - */
+        if(n==0) {
+            *min_offx=offx;
+            *min_offy=offy;
+            *max_offx=offx;
+            *max_offy=offy;
+        } else {
+            if(offx > *max_offx) *max_offx=offx;
+            if(offy > *max_offy) *max_offy=offy;
+            if(offx < *min_offx) *min_offx=offx;
+            if(offy < *min_offy) *min_offy=offy;
+        }
+    }
+
+    return;
+}
 /**
   @brief    Computes size of coadded cube
   @param    offsetx  input offset list
@@ -281,6 +341,9 @@ sinfo_sess2deg(const double sess)
   @param    size_x   input/output coadded cube x size
   @param    size_y   input/output coadded cube y size
   @return   size of  coadded cube
+  @note This routine differs from the sinfo_auto_size_cube5 one because
+  allows to input cubes of size different from the one of a single cube
+  component (64).
 */
 
 int
@@ -293,36 +356,30 @@ sinfo_auto_size_cube(float* offsetx,
                     int* size_y)
 {
 
-  int n=0;
-
   float min_offx=0;
   float max_offx=0;
   float min_offy=0;
   float max_offy=0;
 
+  cpl_ensure(offsetx  != NULL, CPL_ERROR_ILLEGAL_INPUT, NULL);
+  cpl_ensure(offsety  != NULL, CPL_ERROR_ILLEGAL_INPUT, NULL);
+  cpl_ensure(nframes > 0, CPL_ERROR_ILLEGAL_INPUT, NULL);
+  cpl_ensure(*size_x >= 64, CPL_ERROR_ILLEGAL_INPUT, NULL);
+  cpl_ensure(*size_y >= 64, CPL_ERROR_ILLEGAL_INPUT, NULL);
+
   sinfo_msg ("Computation of output cube size") ;
-  for ( n = 0 ; n < nframes ; n++ ) {
-    float offx = offsetx[n];  /* was - */
-    float offy = offsety[n];  /* was - */
-    /* sinfo_msg("frame %d offx=%f offy=%f",n,offx,offy); */
-    if(n==0) {
-      min_offx=offx;
-      min_offy=offy;
-      max_offx=offx;
-      max_offy=offy;
-    } else {
-      if(offx > max_offx) max_offx=offx;
-      if(offy > max_offy) max_offy=offy;
-      if(offx < min_offx) min_offx=offx;
-      if(offy < min_offy) min_offy=offy;
-    }
-  }
-  /*
+  sinfo_get_xy_min_max(nframes, offsetx, offsety,&min_offx,&max_offx,
+                         &min_offy, &max_offy);
+
   sinfo_msg("max_offx=%f max_offy=%f",max_offx,max_offy);
   sinfo_msg("min_offx=%f min_offy=%f",min_offx,min_offy);
-  */
+
   *ref_offx=(min_offx+max_offx)/2;
   *ref_offy=(min_offy+max_offy)/2;
+
+  /* The following to allow to compute the size of output cube in case the input
+   * has size different than 64x64
+   */
   *size_x+=2*floor(max_offx-min_offx+0.5);
   *size_y+=2*floor(max_offy-min_offy+0.5);
   sinfo_msg("Output cube size: %d x %d",*size_x,*size_y);
@@ -333,6 +390,7 @@ sinfo_auto_size_cube(float* offsetx,
 
 }
 
+
 /**
   @brief    Computes size of coadded cube
   @param    cfg          inpout parameters configuration
@@ -341,52 +399,23 @@ sinfo_auto_size_cube(float* offsetx,
   @return   size of coadded cube
 */
 int
-sinfo_auto_size_cube5(object_config * cfg,
+sinfo_auto_size_cube_new(object_config * cfg,
                     float* ref_offx, float* ref_offy,
                     float* min_offx, float* min_offy,
                     float* max_offx, float* max_offy)
 {
 
-
-  int n=0;
-
-  cpl_propertylist * plist=NULL;
+  const int nframes = cfg->nframes;
   sinfo_msg ("Automatic computation of output cube size") ;
-  for ( n = 0 ; n < cfg->nframes ; n++ ) {
-    char* name = cfg->framelist[n] ;
-    plist=cpl_propertylist_load(name,0);
-    float offx = sinfo_pfits_get_cumoffsetx(plist);  /* was - */
-    if(cpl_error_get_code() != CPL_ERROR_NONE) {
-      sinfo_msg_warning(" could not read fits header keyword cummoffsetx!");
-      sinfo_msg_warning(" set it to  0");
-      offx = 0;
-      cpl_error_reset();
-      /* return -1 ; */
-    }
+  float* offsetx = (float*) cpl_calloc(nframes,sizeof(float));
+  float* offsety = (float*) cpl_calloc(nframes,sizeof(float));
 
-    float offy = sinfo_pfits_get_cumoffsety(plist); /* was - */
-    sinfo_free_propertylist(&plist);
-    if(cpl_error_get_code() != CPL_ERROR_NONE) {
-      sinfo_msg_warning(" could not read fits header keyword! cumoffsety") ;
-      sinfo_msg_warning(" set it to 0");
-      offy = 0;
-      cpl_error_reset();
-      /* return -1 ; */
-    }
-    //sinfo_msg("n=%d offx=%f offy=%f",n,offx,offy);
+  sinfo_offset_xy_fill(cfg,  offsetx, offsety);
+  sinfo_get_xy_min_max(nframes, offsetx, offsety,min_offx,max_offx,
+                       min_offy, max_offy);
+  cpl_free(offsetx);
+  cpl_free(offsety);
 
-    if(n==0) {
-      *min_offx=offx;
-      *min_offy=offy;
-      *max_offx=offx;
-      *max_offy=offy;
-    } else {
-      if(offx > *max_offx) *max_offx=offx;
-      if(offy > *max_offy) *max_offy=offy;
-      if(offx < *min_offx) *min_offx=offx;
-      if(offy < *min_offy) *min_offy=offy;
-    }
-  }
   *ref_offx=(*min_offx+*max_offx)/2;
   *ref_offy=(*min_offy+*max_offy)/2;
 
@@ -395,10 +424,10 @@ sinfo_auto_size_cube5(object_config * cfg,
  * for example, if diff in offset is 35.5, the formula gives 72 but 71 would be
  * enough, the following candidate is working fine:
  *   if(cfg->size_x == 0)
-	  cfg->size_x=floor(2.0*(*max_offx-*min_offx + 0.5 - 0.00001))+64 ;
-	  Currently the ticket is suspended, because the formula above
-	  would change the scientific results for the previous data.
-	  The same is actual for Y axis.
+      cfg->size_x=floor(2.0*(*max_offx-*min_offx + 0.5 - 0.00001))+64 ;
+      Currently the ticket is suspended, because the formula above
+      would change the scientific results for the previous data.
+      The same is actual for Y axis.
 */
   if(cfg->size_y == 0) cfg->size_y=2*floor(*max_offy-*min_offy+0.5)+64 ;
 
@@ -411,6 +440,7 @@ sinfo_auto_size_cube5(object_config * cfg,
 
 }
 
+
 /**
   @brief    Read slitlets distances
   @param    nslits input number of slitlets
@@ -1784,6 +1814,37 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky2(cpl_imagelist** cubes,
   return cubes_sky;
 }
 
+static void
+sinfo_set_offset_xy(double mjd_obs,
+                    const double offx, const double offy,const int n,
+                    float* offsetx, float* offsety)
+{
+if (mjd_obs > 53825. ) {
+   /* April 1st 2006 */
+   //sinfo_msg("New cumoffset setting convention");
+   sinfo_new_array_set_value(offsetx,2*offx,n);
+   sinfo_new_array_set_value(offsety,2*offy,n);
+ } else if ((mjd_obs > 53421.58210082 ) && (mjd_obs <= 53825.)){
+   /* after detector's upgrade */
+   /*
+   sinfo_new_array_set_value(offsetx,-offx*2,n);
+   sinfo_new_array_set_value(offsety,+offy*2,n);
+   */
+   sinfo_new_array_set_value(offsetx,-2*offx,n);
+   sinfo_new_array_set_value(offsety,2*offy,n);
+ } else {
+   /* before detector's upgrade */
+   /*
+   sinfo_new_array_set_value(offsetx,+offx*2,n);
+   sinfo_new_array_set_value(offsety,-offy*2,n);
+   */
+   sinfo_new_array_set_value(offsetx,2*offx,n);
+   sinfo_new_array_set_value(offsety,-2*offy,n);
+ }
+
+return;
+
+}
 
 /**
 @brief extracts from each object frame set information
@@ -1798,7 +1859,7 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky2(cpl_imagelist** cubes,
 */
 
 int
-sinfo_new_assign_offset(const int n,
+sinfo_assign_offset_usr(const int n,
                         const char* name,
                         float* offsetx,
                         float* offsety,
@@ -1809,17 +1870,6 @@ sinfo_new_assign_offset(const int n,
   float offx=0;
   float offy=0;
   double mjd_obs=0;
-  /*
-  double pixelscale=0;
-  double angle=0;
-  double radangle=0;
-  double cd1_1=0;
-  double cd1_2=0;
-  double cd2_1=0;
-  double cd2_2=0;
-  double ra=0;
-  double dec=0;
-  */
 
   cpl_propertylist * plist=NULL;
   sinfo_msg_debug("Assign offsets");
@@ -1830,7 +1880,66 @@ sinfo_new_assign_offset(const int n,
     return -1 ;
   }
 
+  offx = offsetx[n] - ref_offx ; // was -
+  offy = offsety[n] - ref_offy ; // was -
+
+
+  sinfo_msg_debug("offx=%f offy=%f",offx,offy);
+
+  if (cpl_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
+    mjd_obs=cpl_propertylist_get_double(plist, KEY_NAME_MJD_OBS);
+  } else {
+    sinfo_msg_error("keyword %s does not exist",KEY_NAME_MJD_OBS);
+    cpl_propertylist_delete(plist) ;
+    return -1;
+  }
+  cpl_propertylist_delete(plist) ;
+  sinfo_set_offset_xy(mjd_obs, offx, offy, n, offsetx, offsety);
+
+  return 0;
+
+
+}
+
+/**
+@brief extracts from each object frame set information
+       relative to the ao setting
+@name sinfo_assign_offset_from_fits_header
+@param n      frame index in list
+@param name   file name
+@param offsetx  reference frame X offset
+@param offsety  reference frame Y offset
+@param ref_setx frames X offset array
+@param ref_sety frames Y offset array
+*/
+
+int
+sinfo_assign_offset_from_fits_header(const int n,
+                        const char* name,
+                        float* offsetx,
+                        float* offsety,
+                        const float ref_offx,
+                        const float ref_offy)
+{
+
+  float offx=0;
+  float offy=0;
+  double mjd_obs=0;
+
+  cpl_propertylist * plist=NULL;
+  sinfo_msg_debug("Assign offsets");
+
+  if ((cpl_error_code)((plist = cpl_propertylist_load(name, 0)) == NULL)) {
+    sinfo_msg_error( "getting header from reference frame %s",name);
+    cpl_propertylist_delete(plist) ;
+    return -1 ;
+  }
+
+
   offx = sinfo_pfits_get_cumoffsetx(plist) - ref_offx ;  /* was - */
+  sinfo_msg("ref_offx=%g frame offsetx=%g assigned offx=%g",
+              ref_offx,sinfo_pfits_get_cumoffsetx(plist),offx);
+
   if(cpl_error_get_code() != CPL_ERROR_NONE) {
     sinfo_msg_warning(" could not read fits header keyword cummoffsetx!") ;
     sinfo_msg_warning(" Set relative offset to 0 - %f!",ref_offx) ;
@@ -1858,226 +1967,7 @@ sinfo_new_assign_offset(const int n,
   }
 
   cpl_propertylist_delete(plist) ;
-
-  if (mjd_obs > 53825. ) {
-    /* April 1st 2006 */
-    //sinfo_msg("New cumoffset setting convention");
-    sinfo_new_array_set_value(offsetx,2*offx,n);
-    sinfo_new_array_set_value(offsety,2*offy,n);
-  } else if ((mjd_obs > 53421.58210082 ) && (mjd_obs <= 53825.)){
-    /* after detector's upgrade */
-    /*
-    sinfo_new_array_set_value(offsetx,-offx*2,n);
-    sinfo_new_array_set_value(offsety,+offy*2,n);
-    */
-    sinfo_new_array_set_value(offsetx,-2*offx,n);
-    sinfo_new_array_set_value(offsety,2*offy,n);
-  } else {
-    /* before detector's upgrade */
-    /*
-    sinfo_new_array_set_value(offsetx,+offx*2,n);
-    sinfo_new_array_set_value(offsety,-offy*2,n);
-    */
-    sinfo_new_array_set_value(offsetx,2*offx,n);
-    sinfo_new_array_set_value(offsety,-2*offy,n);
-  }
-
-  return 0;
-
-
-}
-
-
-
-
-
-/**
-@brief extracts from each object frame set information
-       relative to the ao setting
-@name sinfo_new_assign_offset
-@param n      frame index in list
-@param name   file name
-@param offsetx  reference frame X offset
-@param offsety  reference frame Y offset
-@param offsetx frames X offset array
-@param offsety frames Y offset array
-*/
-
-int
-sinfo_new_assign_offset2(const int n,
-                        const char* name,
-                        float* offsetx,
-                        float* offsety,
-                        const float ref_offx,
-                        const float ref_offy)
-{
-
-  float offx=0;
-  float offy=0;
-  double mjd_obs=0;
-
-  cpl_propertylist * plist=NULL;
-  sinfo_msg_debug("Assign offsets as set by user");
-  offx = offsetx[n] - ref_offx ;  /* was - */
-  offy = offsety[n] - ref_offy ;  /* was - */
-  sinfo_msg_debug("offx=%f offy=%f",offx,offy);
-
-  sinfo_msg_debug("Assign offsets");
-
-  if ((cpl_error_code)((plist = cpl_propertylist_load(name, 0)) == NULL)) {
-    sinfo_msg_error( "getting header from reference frame %s",name);
-    cpl_propertylist_delete(plist) ;
-    return -1 ;
-  }
-
-  if (cpl_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
-    mjd_obs=cpl_propertylist_get_double(plist, KEY_NAME_MJD_OBS);
-  } else {
-    sinfo_msg_error("keyword %s does not exist",KEY_NAME_MJD_OBS);
-    cpl_propertylist_delete(plist) ;
-    return -1;
-  }
-  cpl_propertylist_delete(plist) ;
-
-  //sinfo_new_array_set_value(offsetx,-2*offx,n);
-  //sinfo_new_array_set_value(offsety,2*offy,n);
-
-  if (mjd_obs > 53825. ) {
-    /* April 1st 2006 */
-    //sinfo_msg("New cumoffset setting convention");
-    sinfo_new_array_set_value(offsetx,2*offx,n);
-    sinfo_new_array_set_value(offsety,2*offy,n);
-  } else if ((mjd_obs > 53421.58210082 ) && (mjd_obs <= 53825.)){
-    /* after detector's upgrade */
-    /*
-    sinfo_new_array_set_value(offsetx,-offx*2,n);
-    sinfo_new_array_set_value(offsety,+offy*2,n);
-    */
-    sinfo_new_array_set_value(offsetx,-2*offx,n);
-    sinfo_new_array_set_value(offsety,2*offy,n);
-  } else {
-    /* before detector's upgrade */
-    /*
-    sinfo_new_array_set_value(offsetx,+offx*2,n);
-    sinfo_new_array_set_value(offsety,-offy*2,n);
-    */
-    sinfo_new_array_set_value(offsetx,2*offx,n);
-    sinfo_new_array_set_value(offsety,-2*offy,n);
-  }
-
-
-  return 0;
-
-
-}
-
-
-/**
-@brief extracts from each object frame set information
-       relative to the ao setting
-@name sinfo_new_assign_offset
-@param n      frame index in list
-@param name   file name
-@param offsetx  reference frame X offset
-@param offsety  reference frame Y offset
-@param offsetx frames X offset array
-@param offsety frames Y offset array
-*/
-/* TODO: not used */
-int
-sinfo_new_object_assign_offset(const char* name,
-                               const int n,
-                               double* ref_offx,
-                               double* ref_offy,
-                               float** offsetx,
-                               float** offsety)
-{
-
-  float offx=0;
-  float offy=0;
-  double mjd_obs=0;
-  cpl_propertylist * plist=NULL;
-  sinfo_msg_debug("Assign offsets");
-
-  if ((cpl_error_code)((plist = cpl_propertylist_load(name, 0)) == NULL)) {
-    sinfo_msg_error( "getting header from reference frame %s",name);
-    cpl_propertylist_delete(plist) ;
-    return -1 ;
-  }
-  if ( n == 0 ) {
-
-    *ref_offx = sinfo_pfits_get_cumoffsetx(plist) ;
-    if(cpl_error_get_code() != CPL_ERROR_NONE) {
-      sinfo_msg_error(" could not read fits header keyword cummoffsetx!") ;
-      /* return -1 ; */
-      cpl_error_reset();
-    }
-
-    *ref_offy = sinfo_pfits_get_cumoffsety(plist) ;
-    if(cpl_error_get_code() != CPL_ERROR_NONE) {
-      sinfo_msg_error(" could not read fits header keyword! cumoffsety") ;
-      cpl_error_reset();
-       /* return -1 ; */
-    }
-    sinfo_msg_debug("Reference offx=%f offy=%f",*ref_offx,*ref_offy);
-
-    offx = 0. ;
-    offy = 0. ;
-
-  } else {
-
-    offx = sinfo_pfits_get_cumoffsetx(plist) - *ref_offx ;  /* was - */
-    if(cpl_error_get_code() != CPL_ERROR_NONE) {
-      sinfo_msg_error(" could not read fits header keyword cummoffsetx!") ;
-      cpl_error_reset();
-      /* return -1 ; */
-    }
-
-    offy = sinfo_pfits_get_cumoffsety(plist) - *ref_offy ; /* was - */
-    if(cpl_error_get_code() != CPL_ERROR_NONE) {
-      sinfo_msg_error(" could not read fits header keyword! cumoffsety") ;
-      /* return -1 ; */
-      cpl_error_reset();
-    }
-    sinfo_msg_debug("offx=%f offy=%f",offx,offy);
-  }
-
-
-    /* rotate the coordinates
-       offx_rot = cd1_1 * offx + cd2_1 * offy ;
-       offy_rot = cd1_2 * offx + cd2_2 * offy ;
-        convert the coordinates to pixel units
-       offx_rot_pix = offx_rot / pixelscale ;
-       offy_rot_pix = offy_rot / pixelscale ;
-       offsetx[i] = offx_rot_pix ;
-       offsety[i] = offy_rot_pix ;
-    */
-
-
-  if (cpl_propertylist_has(plist, KEY_NAME_MJD_OBS)) {
-    mjd_obs=cpl_propertylist_get_double(plist, KEY_NAME_MJD_OBS);
-  } else {
-    sinfo_msg_error("keyword %s does not exist",KEY_NAME_MJD_OBS);
-    cpl_propertylist_delete(plist) ;
-    return -1;
-  }
-
-  cpl_propertylist_delete(plist) ;
-
-  if (mjd_obs > 53825. ) {
-    /* April 1st 2006 */
-    //sinfo_msg("New cumoffset setting convention");
-    sinfo_new_array_set_value(*offsetx,2*offx,n);
-    sinfo_new_array_set_value(*offsety,2*offy,n);
-  } else if ((mjd_obs > 53421.58210082 ) && (mjd_obs <= 53825.)){
-    /* after detector's upgrade */
-    sinfo_new_array_set_value(*offsetx,-offx*2,n);
-    sinfo_new_array_set_value(*offsety,+offy*2,n);
-  } else {
-    /* before detector's upgrade */
-    sinfo_new_array_set_value(*offsetx,+offx*2,n);
-    sinfo_new_array_set_value(*offsety,-offy*2,n);
-  }
+  sinfo_set_offset_xy(mjd_obs, offx, offy, n, offsetx, offsety);
 
   return 0;
 }
