@@ -33,7 +33,11 @@ sinfo_read_distances(const int nslits, const char* distlist);
 float** 
 sinfo_read_slitlets_edges(const int nslits, const char* poslist);
 
-
+int
+sinfo_auto_size_cube_new(object_config * cfg,
+                    float* ref_offx, float* ref_offy,
+                    float* min_offx, float* min_offy,
+                    float* max_offx, float* max_offy);
 int 
 sinfo_check_input_data(object_config* cfg);  
 
@@ -91,20 +95,15 @@ sinfo_new_fine_tune(cpl_imagelist* cube,float* correct_dist,
                     const char* method, const int order, const int nslits) ;
 
 int
-sinfo_new_object_assign_offset(const char* name, const int n, double* ref_offx, 
-                               double* ref_offy, float** offsetx, 
-                               float** offsety);
-
-int
-sinfo_new_assign_offset2(const int n,
+sinfo_assign_offset_usr(const int n,
                         const char* name,
                         float* offsetx,
                         float* offsety,
                         const float ref_offx,
-             const float ref_offy);
+                        const float ref_offy);
 
 int
-sinfo_new_assign_offset(const int n,const char* name,float* offsetx,
+sinfo_assign_offset_from_fits_header(const int n,const char* name,float* offsetx,
                         float* offsety,const float ref_offx,
                         const float ref_offy);
 
